@@ -32,19 +32,19 @@ class BackendBase:
         pass
 
     async def download_file(self, url, path, buffer_size=4096):
-        retry_opts = ExponentialRetry(attempts=3)
-        async with RetryClient(retry_options=retry_opts) as session:
-            async with session.get(url) as response:
-                if response.status == 200:
-                    with open(path, mode='wb') as f:
-                        while True:
-                            chunk = await response.content.read(buffer_size)
-                            if not chunk:
-                                break
-                            f.write(chunk)
-                else:
-                    raise ValueError()
-        # wget.download(url, path)
+        # retry_opts = ExponentialRetry(attempts=3)
+        # async with RetryClient(retry_options=retry_opts) as session:
+        #     async with session.get(url) as response:
+        #         if response.status == 200:
+        #             with open(path, mode='wb') as f:
+        #                 while True:
+        #                     chunk = await response.content.read(buffer_size)
+        #                     if not chunk:
+        #                         break
+        #                     f.write(chunk)
+        #         else:
+        #             raise ValueError()
+        wget.download(url, path)
 
     def create_dir_if_not_exists(self, path):
         os.makedirs(os.path.split(path)[0], exist_ok=True)
