@@ -74,16 +74,35 @@ class WYSF(BackendBase):
 
                 if os.path.isfile(download_path):
                     os.remove(download_path)
+                self.create_dir_if_not_exists(download_path)
                 wget.download(url, download_path)
                 return True, download_path
         except Exception as e:
+            traceback.print_exc()
             if tries >= 3:
                 return False, str(e)
             else:
                 return self.get(download_path, bucket, bucket_name, tries+1)
 
-    async def get_async(self, download_path, bucket, bucket_name):
-        return self.get(download_path, bucket, bucket_name)
+    async def get_async(self, download_path, bucket, bucket_name, tries=0):
+        try:
+            if tries >= 3:
+                return False, '下载出错'
+            else:
+                url = 'http://{}/{}'.format(self.domain, '{}_{}'.format(bucket, bucket_name))
+                print('downloading {} -> {}'.format(url, download_path))
+
+                if os.path.isfile(download_path):
+                    os.remove(download_path)
+                self.create_dir_if_not_exists(download_path)
+                await self.download_file(url, download_path)
+                return True, download_path
+        except Exception as e:
+            traceback.print_exc()
+            if tries >= 3:
+                return False, str(e)
+            else:
+                return await self.get_async(download_path, bucket, bucket_name, tries+1)
 
     async def cleanup_old_files(self):
         objects = self.client.list_objects(self.default_bucket, prefix='tmp_file', limit=1000)
@@ -122,7 +141,7 @@ if __name__ == '__main__':
         'domain': 'hamuna-images.nos-eastchina1.126.net',
         'default_bucket': 'hamuna-images'
     })
-    asyncio.get_event_loop().run_until_complete(client.cleanup_old_files())
+    # asyncio.get_event_loop().run_until_complete(client.cleanup_old_files())
 
 
             
