@@ -137,6 +137,8 @@ class MQManager(Singleton):
         except ConnectionClosedError as e:
             await self.close_async()
             return await self.__mq_pub(topic, message, None, tries+1)
+        except:
+            traceback.print_exc()
 
 
     async def async_publish(self, topic, message, mq=None):
@@ -149,9 +151,6 @@ class MQManager(Singleton):
                 message = orjson.dumps(message)
             print('publishing')
 
-            if mq is None:
-                mq = await self.get_mq_conn()
-
             ret = await self.__mq_pub(topic, message)
             return ret
         except Exception as e:
